from intuitive_vectorscript.dialog_item import Item


# Super class for value field, inherited of class 'Item'
class ValueField(Item):

	def __init__(self, dialog, item_id: int, item_type, chars):
		super().__init__(dialog, item_id, item_type, chars)
		self.default_value = ""
		self.is_editable = True

	def set_editable(self, is_editable: bool):
		self.is_editable = is_editable

	def activation(self):
		vs.EnableTextEdit(self.dialog.dialog_id, self.item_id, self.is_editable)


# class TextField for field items with string as input
class TextField(ValueField):

	@staticmethod
	def set_default_value(default_value: str):
		ValueField.default_value = default_value

	def run(self):
		vs.CreateEditText(self.dialog.dialog_id, self.item_id, self.default_value, self.chars)


# class IntegerField for field items with integer as input
class IntegerField(ValueField):

	@staticmethod
	def set_default_value(default_value: int):
		ValueField.default_value = default_value

	def run(self):
		vs.CreateEditInteger(self.dialog.dialog_id, self.item_id, self.default_value, self.chars)



from intuitive_vectorscript.dialog_item import Item


class MultipleChoicesItems(Item):

	def __init__(self, dialog, item_id: int, item_type, chars):
		super().__init__(dialog, item_id, item_type, chars)
		self.choices = None
		self.has_listener = True

	def add_choices(self, choices: dict):
		self.choices = choices

	def activation(self):
		if self.has_listener:
			vs.NotifyPullDownClicked(self.dialog.dialog_id, self.item_id)
		for item in self.choices.items():
			vs.AddChoice(self.dialog.dialog_id, self.item_id, item[1], item[0])


# Class PDMenu for pull down menu items
class PDMenu(MultipleChoicesItems):

	def __init__(self, dialog, item_id: int, item_type, chars):
		super().__init__(dialog, item_id, item_type, chars)
		self.has_search = False

	def set_has_search(self, has_search: bool):
		self.has_search = has_search

	def run(self):
		if self.has_search:
			vs.CreatePullDownSearch(self.dialog.dialog_id, self.item_id, self.chars)
		else:
			vs.CreatePullDownMenu(self.dialog.dialog_id, self.item_id, self.chars)


class ClassPDMenu(MultipleChoicesItems):

	def run(self):
		vs.CreateClassPullDownMenu(self.dialog.dialog_id, self.item_id, self.chars)

	def activation(self):
		pass


class LayerPDMenu(MultipleChoicesItems):

	def run(self):
		vs.CreateLayerPDMenu(self.dialog.dialog_id, self.item_id, self.chars)

	def activation(self):
		pass


class SheetLayerPDMenu(MultipleChoicesItems):

	def run(self):
		vs.CreateSheetLayerPullDownMenu(self.dialog.dialog_id, self.item_id, self.chars)

	def activation(self):
		pass


class EnhancedPDMenu(MultipleChoicesItems):

	def __init__(self, dialog, item_id: int, item_type, chars):
		super().__init__(dialog, item_id, item_type, chars)
		self.show_icon = True

	def run(self):
		vs.CreateEnhancedPullDownMenu(self.dialog.dialog_id, self.item_id, self.chars, self.show_icon)

	def set_icon_visibility(self, show_icon: bool):
		self.show_icon = show_icon

	def activation(self):
		pass





# Super Class Item, basic variables and functions for all items in dialog
class Item:
	def __init__(self, dialog, item_id: int, item_type, chars):
		self.dialog = dialog
		self.item_id = item_id
		self.item_type = item_type
		self.chars = chars
		self.bounding_right = {"fixed_binding": True, "prop_binding": False}
		self.bounding_left = {"fixed_binding": True, "prop_binding": False}
		self.bounding_bottom = {"fixed_binding": False, "prop_binding": True}
		self.bounding_top = {"fixed_binding": False, "prop_binding": False}

	def activation(self):
		pass

	def set_alignment(self, alignment="r", mode="resize", alignment_id: int = 1):

		if alignment == "r":
			alignment = 1
		elif alignment == "bottom":
			alignment = 2
		elif alignment == "left":
			alignment = 3

		if mode == "resize":
			mode = 0
		else:
			mode = 1

		vs.AlignItemEdge(self.dialog.dialog_id, self.item_id, alignment, alignment_id, mode)

	def set_bounding(self, right: dict = None, left: dict = None, bottom: dict = None,
					 top: dict = None):
		if right is None:
			self.bounding_right = {"fixed_binding": True, "prop_binding": False}
		else:
			self.bounding_right = right
		if left is None:
			self.bounding_left = {"fixed_binding": True, "prop_binding": False}
		else:
			self.bounding_left = left
		if bottom is None:
			self.bounding_bottom = {"fixed_binding": False, "prop_binding": True}
		else:
			self.bounding_bottom = bottom
		if top is None:
			self.bounding_top = {"fixed_binding": False, "prop_binding": False}
		else:
			self.bounding_top = top

	def bounding(self):
		vs.SetEdgeBinding(self.dialog.dialog_id, self.item_id, self.bounding_left["fixed_binding"],
						  self.bounding_right["fixed_binding"], self.bounding_top["fixed_binding"],
						  self.bounding_bottom["fixed_binding"])
		vs.SetProportionalBinding(self.dialog.dialog_id, self.item_id, self.bounding_left["prop_binding"],
						  self.bounding_right["prop_binding"], self.bounding_top["prop_binding"],
						  self.bounding_bottom["prop_binding"])



from intuitive_vectorscript.item_multiple_choices import *
from intuitive_vectorscript.item_single_value_field import *
from intuitive_vectorscript.dialog_item import *
from intuitive_vectorscript.dialog import *
from intuitive_vectorscript.usefull_classes import *
from intuitive_vectorscript.usefull_functions import *





def MyGetPlugInString(ndx):
	# {Static Text}
	GetPlugInString = ''
	if ndx == 1001:
		GetPlugInString = 'OK'
	elif ndx == 1002:
		GetPlugInString = 'Cancel'
	elif ndx == 1003:
		GetPlugInString = 'Sample Dialog 2'
	elif ndx == 1004:
		GetPlugInString = 'List Box'
	elif ndx == 1005:
		GetPlugInString = ''
	elif ndx == 1006:
		GetPlugInString = 'List Browser'
	elif ndx == 1007:
		GetPlugInString = ''
	elif ndx == 1008:
		GetPlugInString = ''
	# {Help Text}
	if ndx == 2001:
		GetPlugInString = 'Accepts the dialog data.'
	elif ndx == 2002:
		GetPlugInString = 'Cancels the dialog data.'
	elif ndx == 2004:
		GetPlugInString = ''
	elif ndx == 2005:
		GetPlugInString = 'This is list box control.'
	elif ndx == 2006:
		GetPlugInString = ''
	elif ndx == 2007:
		GetPlugInString = 'This is list browser control.'
	elif ndx == 2008:
		GetPlugInString = 'Tabbed content list box. This list box contains rows with two strings with tab delimiter. This causes the list to have two columns.'
	return GetPlugInString


def GetStr(ndx):
	return MyGetPlugInString(ndx + 1000)


def GetHelpStr(ndx):
	return MyGetPlugInString(ndx + 2000)


def SampleDlg2():
	# {Alignment constants}
	kRight = 1;
	kBottom = 2;
	kLeft = 3;
	kColumn = 4;
	kResize = 0;
	kShift = 1;

	# { default and cancel button IDs}
	kOK = 1;
	kCancel = 2;

	# { control IDs}
	kListBoxText = 4;
	kListBox1 = 5;
	kListBrowserText = 6;
	kListBrowser = 7;
	kListBox2 = 8;

	dialog = vs.CreateResizableLayout(GetStr(3), True, GetStr(kOK), GetStr(kCancel), True, True);

	# {create controls}
	vs.CreateStaticText(dialog, kListBoxText, GetStr(kListBoxText), -1);
	vs.CreateListBox(dialog, kListBox1, 25, 10);
	vs.CreateListBox(dialog, kListBox2, 25, 10);
	vs.CreateStaticText(dialog, kListBrowserText, GetStr(kListBrowserText), -1);
	vs.CreateLB(dialog, kListBrowser, 50, 10);

	# {set relations}
	vs.SetFirstLayoutItem(dialog, kListBoxText);
	vs.SetBelowItem(dialog, kListBoxText, kListBox1, 0, 0);
	vs.SetRightItem(dialog, kListBox1, kListBox2, 0, 0);
	vs.SetBelowItem(dialog, kListBox1, kListBrowserText, 0, 0);
	vs.SetBelowItem(dialog, kListBrowserText, kListBrowser, 0, 0);

	# {set alignments}
	vs.AlignItemEdge(dialog, kListBrowser, kRight, 1, kResize);
	vs.AlignItemEdge(dialog, kListBox2, kRight, 1, kResize);

	# {set bindings}
	vs.SetEdgeBinding(dialog, kListBox1, True, True, False, False);
	vs.SetProportionalBinding(dialog, kListBox1, False, True, False, False);
	vs.SetEdgeBinding(dialog, kListBox2, True, True, False, False);
	vs.SetProportionalBinding(dialog, kListBox2, True, False, False, False);

	# {set help strings}
	for cnt in range(1, 8):
		vs.SetHelpText(dialog, cnt, GetHelpStr(cnt))

	if vs.RunLayoutDialog(dialog, None) == 1:
		pass


SampleDlg2()



import intuitive_vectorscript as ivs


class Dialog:
	setup_dialog_c = 12255

	def __init__(self, dialog_title, resizeable: bool = True, has_help: bool = False, button_name_default="OK",
				 button_name_cancel="Cancel"):

		self.control_ids = {}  # Container for the control IDS of the items in format 'control_ID = instance'
		self.item_base_id = 30  # Item counter for control IDs

		self.dialog_title = dialog_title
		self.dialog_id = self.create_layout(resizeable, has_help, button_name_default,
											button_name_cancel)  # Dialog handle

	def dialog_event_handler(self, item, data):
		if item == self.setup_dialog_c:
			for instance in self.control_ids.values():
				instance.activation()

	def reset_choice_sample(self):
		for key in self.control_ids.keys():
			self.control_ids[0] = self.control_ids.pop(key)

	def create_layout(self, resizeable, has_help, btn_1, btn_2):
		if resizeable:
			dialog = vs.CreateResizableLayout(self.dialog_title, has_help, btn_1, btn_2, True, True)
		else:
			dialog = vs.CreateLayout(self.dialog_title, has_help, btn_1, btn_2)
		return dialog

	def create_item(self, index: int, item_type: str, chars: int = 24, has_listener: bool = True):

		def instantiate_item(item_class):
			item = item_class(self, self.item_base_id + index, item_type, chars)
			self.control_ids[item.item_id] = item
			return item

		if item_type == "TextField":
			item_inst = instantiate_item(ivs.TextField)
			return item_inst
		elif item_type == "IntegerField":
			item_inst = instantiate_item(ivs.IntegerField)
			return item_inst
		elif item_type == "PDMenu":
			item_inst = instantiate_item(ivs.PDMenu)
			return item_inst
		elif item_type == "EnhancedPDMenu":
			item_inst = instantiate_item(ivs.EnhancedPDMenu)
			return item_inst
		elif item_type == "ClassPDMenu":
			item_inst = instantiate_item(ivs.ClassPDMenu)
			return item_inst
		elif item_type == "LayerPDMenu":
			item_inst = instantiate_item(ivs.LayerPDMenu)
			return item_inst
		elif item_type == "SheetLayerPDMenu":
			item_inst = instantiate_item(ivs.SheetLayerPDMenu)
			return item_inst

	def set_dialog_order(self):
		vs.SetFirstLayoutItem(self.dialog_id, self.item_base_id)
		for cid in self.control_ids.keys():
			vs.SetBelowItem(self.dialog_id, cid, cid + 1, 0, 0)

	def create_my_dialog(self):
		for instance in self.control_ids.values():
			instance.run()
		self.set_dialog_order()
		for instance in self.control_ids.values():
			instance.set_alignment()
			instance.bounding()
		if vs.RunLayoutDialog(self.dialog_id, self.dialog_event_handler) == 1:
			pass



import intuitive_vectorscript as ivs

dialog = ivs.Dialog("Test")

item1 = dialog.create_item(0, "TextField")
item2 = dialog.create_item(1, "PDMenu")
item3 = dialog.create_item(2, "IntegerField")
item4 = dialog.create_item(3, "PDMenu")
item5 = dialog.create_item(4, "ClassPDMenu")
item6 = dialog.create_item(5, "LayerPDMenu")
item7 = dialog.create_item(6, "SheetLayerPDMenu")

item3.set_default_value(120)
item1.set_default_value("12")

arg = {0: "test", 1: "fsü"}
item2.add_choices(arg)
item4.add_choices(arg)
item7.set_bounding(bottom={"fixed_binding": True, "prop_binding": False})

item3.set_editable(False)
dialog.create_my_dialog()





class Room:

	def __init__(self, handle):
		self.handle = handle
		self.raumnummer = vs.GetRField(self.handle, "DB_SPACE", "SpaceNumber")


class Floor:
	def __init__(self, handle):
		self.handle = handle
		self.bounding_space = None
		self.components = {}

	def get_components(self):
		nums = vs.GetNumberOfComponents(self.handle)
		for i in range(nums[1] + 1):
			name = vs.GetComponentName(self.handle, i)
			height = vs.GetComponentWidth(self.handle, i)
			self.components[name] = height[1]

		self.components.pop("")

		return self.components
